"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var redux_saga_1 = require("redux-saga");
var SagaRunner = /** @class */ (function () {
    function SagaRunner(sagaOptions) {
        if (sagaOptions === void 0) { sagaOptions = {}; }
        this.sagaOptions = sagaOptions;
        this.subscribes = [];
        this.stores = {};
        this.subscribe = this.subscribe.bind(this);
        this.dispatch = this.dispatch.bind(this);
        var runSagaOptions = {
            subscribe: this.subscribe,
            dispatch: this.dispatch,
            getState: this.getState
        };
        if (this.sagaOptions.monitor) {
            runSagaOptions.sagaMonitor = this.sagaOptions.monitor;
        }
        this.bindRunSaga = this.rawRunSaga.bind(this, runSagaOptions);
    }
    SagaRunner.prototype.dispatch = function (action) {
        var arr = this.subscribes.slice();
        for (var i = 0, len = arr.length; i < len; i++) {
            arr[i](action);
        }
        if (process.env.NODE_ENV === 'development' || process.env.SAGA_LOG) {
            console.groupCollapsed("Action: " + action.type);
            console.log(action.payload);
            console.groupEnd();
        }
        return action;
    };
    SagaRunner.prototype.getState = function () {
        return this.stores;
    };
    SagaRunner.prototype.runSaga = function (saga) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return this.bindRunSaga.apply(this, [saga].concat(args));
    };
    SagaRunner.prototype.registerStore = function (key, store) {
        if (this.stores[key]) {
            throw new Error('已存在key: ' + key);
        }
        this.stores[key] = store;
    };
    SagaRunner.prototype.unRegisterStore = function (key) {
        if (this.stores[key]) {
            delete this.stores[key];
        }
    };
    SagaRunner.prototype.useSagaMiddleware = function (middleware) {
        this.sagaMiddleware = middleware;
    };
    SagaRunner.prototype.subscribe = function (callback) {
        var _this = this;
        this.subscribes.push(callback);
        return function () {
            var index = _this.subscribes.indexOf(callback);
            if (index >= 0) {
                _this.subscribes.splice(index, 1);
            }
        };
    };
    SagaRunner.prototype.rawRunSaga = function (options, saga) {
        if (this.sagaMiddleware) {
            return this.sagaMiddleware.run(saga);
        }
        return redux_saga_1.runSaga(options, saga);
    };
    return SagaRunner;
}());
exports.default = SagaRunner;
//# sourceMappingURL=SagaRunner.js.map